/**
 *
 * @author    Jerry Bendy
 * @since     2/26/2018
 */

import callBridge from './callBridge'
import hmacsha1 from 'hmacsha1'

var noop = function() {};

export default {
    post: function(url, data, options) {
        if (typeof url === 'object' && !data && !options) {
            options = url

        } else {
            Object.assign(options, {
                url: url,
                data: data
            })
        }

        makeRequest('POST', options)
    },

    get: function(url, options) {
        if (typeof url === 'object' && !options) {
            options = url
        } else {
            Object.assign(options, {
                url: url
            })
        }

        makeRequest('GET', options)
    },

    ajax: function(options) {
        makeRequest('', options)
    }
}

function makeRequest(type, params) {
    params = Object.assign({}, {
        type: type || 'GET',
        url: '',
        headers: {},
        data: '',
        withSignature: false,   // 接口是否需要签名认证
        timeout: 10000,
        withCredentials: false,
        success: noop,
        error: noop,
        complete: noop
    }, params)

    var xhr = new XMLHttpRequest();

    xhr.open(params.type, params.url);
    xhr.timeout = params.timeout;

    // 获取请求基本 header 内容
    var userSession = callBridge('GET_USER') || {},
        headers = Object.assign({}, {
            appName: userSession.appName || 'ciq3',
            appVersion: userSession.appVersion || '',
            sysType: userSession.sysType || '',
            sysVersion: userSession.sysVersion || '',
            deviceId: userSession.deviceId || '',
            sessionId: userSession.sessionId || '',
            lang: userSession.lang || 'zh'
        }, params.headers)

    // 计算签名
    if (params.withSignature) {
        headers.sign = sign(params.data);
    }

    // 生成请求正文
    var _data = null;

    if (params.data) {
        if (typeof params.data === 'object') {
            if (/json/i.test(headers['Content-type'])) {
                _data = JSON.stringify(params.data)
            } else {
                headers['Content-Type'] = 'application/x-www-form-urlencoded; charset=UTF-8';
                _data = (new URLSearchParams(params.data)).toString();
            }

        } else {
            _data = params.data;
        }
    }

    // 设置 header
    for (var i in headers) {
        if (headers.hasOwnProperty(i)) {
            xhr.setRequestHeader(i, headers[i])
        }
    }

    xhr.send(_data);

    xhr.onreadystatechange = function () {
        if (xhr.readyState === 4) {
            if (xhr.responseText) {
                try {
                    var result = JSON.parse(xhr.responseText);
                    params.success(result, xhr);
                    params.complete(xhr);

                } catch (e) {
                    params.success(xhr.responseText, xhr)
                    params.complete(xhr);
                }
            }
        }
    };
    xhr.ontimeout = function (e) {
        params.error(e, xhr);
        params.complete(xhr);
    };
    xhr.onerror = function (e) {
        params.error(e, xhr);
        params.complete(xhr);
    };
}

/**
 * 请求数据签名
 *
 * @param data
 * @returns {string}
 */
function sign(data) {
    var str = Object.keys(data).sort().map(function(key) {
        return key + '=' + data[key];
    }).join('&');

    return hmacsha1('tQbPwzcmERdu', str);
}
