/**
 *
 * @author    Jerry Bendy
 * @since     2/26/2018
 */

import ciq from '../providers/ciq'
import wechat from '../providers/wechat'

var providers = {
        ciq: ciq,
        wechat: wechat
    },
    clientType = '';

/**
 * 直接调用 JS Bridge 方法，并对返回值尝试解析，如果传入数据中包含成功或失败的
 * 回调会直接使用该回调，同时返回最终值到调用方
 *
 * @param key
 * @param data
 * @param needPrefix   Key 是否需要添加 JS_BRIDGE_ 前缀
 * @param parseResult 是否以 JSON 格式解析返回值
 * @returns {null|object}
 */
export default function(key, data, needPrefix /* = true */, parseResult /* = true */) {
    console.log(arguments)
    if (typeof needPrefix === 'undefined') needPrefix = true;
    if (typeof parseResult === 'undefined') parseResult = true;

    if (!clientType) {
        clientType = getClientType();
    }

    if (!clientType || typeof providers[clientType] === 'undefined') {
        return null;
    }

    try {
        var provider = providers[clientType],
            result = provider(needPrefix ? 'JS_BRIDGE_' + key : key, data)

        if (parseResult && result && typeof result === 'string') {
            return JSON.parse(result);
        }

        return result;

    } catch (e) {
        console.warn(e);
        return null;
    }
}

/**
 * 获取当前支持的客户端类型
 *
 * @returns {string}
 */
function getClientType() {
    var ua = navigator.userAgent;

    if (/MicroBenefitsCIQ/.test(ua)) {
        return 'ciq';
    } else if (/MicroMessenger/.test(ua)) {
        return 'wechat';
    }

    return '';
}